﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;
using System.Data;
using Infragistics.Controls.Schedules;
using System.Collections.ObjectModel;
using System.IO.IsolatedStorage;
using System.IO;
using System.Xml.Serialization;

namespace DataTableSource
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        const string IsoFile = "Falorites.xml";
        public DataSet ScheduleSource = new DataSet();
        public ObservableCollection<MyResource> MyResources { get; set; }
        public ObservableCollection<MyResourceCalendar> MyResourceCalendars { get; set; }
        public ObservableCollection<MyAppointment> MyAppointments { get; set; }

        public MainWindow()
        {
            InitializeComponent();
            InitialzieDataSet();
            InitializeObjectSource();

            dataConnector.ResourceItemsSource = MyResources;//ScheduleSource.Tables["Resources"].DefaultView;
            dataConnector.ResourcePropertyMappings = new ResourcePropertyMappingCollection() { UseDefaultMappings = true };

            dataConnector.ResourceCalendarItemsSource = MyResourceCalendars;//ScheduleSource.Tables["ResourceCalendars"].DefaultView;
            dataConnector.ResourceCalendarPropertyMappings = new ResourceCalendarPropertyMappingCollection { UseDefaultMappings = true };

            dataConnector.AppointmentItemsSource = MyAppointments;//ScheduleSource.Tables["Appointments"].DefaultView;
            dataConnector.AppointmentPropertyMappings = new AppointmentPropertyMappingCollection { UseDefaultMappings = true };





            dataConnector1.ResourceItemsSource = ScheduleSource.Tables["Resources"].DefaultView;
            dataConnector1.ResourcePropertyMappings = new ResourcePropertyMappingCollection() { UseDefaultMappings = true };

            dataConnector1.ResourceCalendarItemsSource = ScheduleSource.Tables["ResourceCalendars"].DefaultView;
            dataConnector1.ResourceCalendarPropertyMappings = new ResourceCalendarPropertyMappingCollection { UseDefaultMappings = true };

            dataConnector1.AppointmentItemsSource = ScheduleSource.Tables["Appointments"].DefaultView;
            dataConnector1.AppointmentPropertyMappings = new AppointmentPropertyMappingCollection { UseDefaultMappings = true }; 
        }

        public void InitialzieDataSet()
        {
            //Resources
            DataTable resources = new DataTable("Resources");
            resources.Columns.Add("Id", typeof(String));
            resources.Columns.Add("Name", typeof(String));

            resources.Rows.Add(new object[] { "own1", "Amanda" });
            resources.AcceptChanges();
            ScheduleSource.Tables.Add(resources);

            //Resource Calendars
            DataTable calendars = new DataTable("ResourceCalendars");
            calendars.Columns.Add("Id", typeof(String));
            calendars.Columns.Add("OwningResourceId", typeof(String));

            calendars.Rows.Add(new object[] { "cal1", "own1" });
            calendars.AcceptChanges();
            ScheduleSource.Tables.Add(calendars);

            //Appointments
            DataTable appointments = new DataTable("Appointments");
            appointments.Columns.Add("Id", typeof(string));
            appointments.Columns.Add("Start", typeof(DateTime));
            appointments.Columns.Add("End", typeof(DateTime));
            appointments.Columns.Add("OwningResourceId", typeof(string));
            appointments.Columns.Add("OwningCalendarId", typeof(string));
            appointments.Columns.Add("Subject", typeof(string));
            MyAppointments = new ObservableCollection<MyAppointment>();
            for (int i = 0; i < 5; i++)
            {
                appointments.Rows.Add(
                    new object[]
                    {
                        "app" + i,
                        DateTime.Now.AddHours(i),
                        DateTime.Now.AddHours(i + 1.5),
                        "own1",
                        "cal1",
                        "Subject " + i
                    });
            }
            appointments.AcceptChanges();
            ScheduleSource.Tables.Add(appointments);

            ScheduleSource.AcceptChanges();
        }

        public void InitializeObjectSource()
        {
            //Resources
            MyResources = new ObservableCollection<MyResource>();
            MyResources.Add(new MyResource { Id = "own1", Name = "Amanda" });

            //Resource Calendars
            MyResourceCalendars = new ObservableCollection<MyResourceCalendar>();
            MyResourceCalendars.Add(new MyResourceCalendar { Id = "cal1", OwningResourceId = "own1" });

            //Appointments
            MyAppointments = new ObservableCollection<MyAppointment>();
            for (int i = 0; i < 5; i++)
            {
                MyAppointments.Add(
                    new MyAppointment
                    {
                        Id = "app" + i,
                        Start = DateTime.Now.AddHours(i),
                        End = DateTime.Now.AddHours(i + 1.5),
                        OwningResourceId = "own1",
                        OwningCalendarId = "cal1",
                        Subject = "Subject " + i
                    });
            }
        }

        private static void WriteDataToStore(byte[] data, string fileName)
        {
            if (data == null || data.Length == 0)
                return;

            using (var store = IsolatedStorageFile.GetStore(IsolatedStorageScope.User | IsolatedStorageScope.Domain | IsolatedStorageScope.Assembly, null, null))
            {
                CleanStorage(store);

                IsolatedStorageFileStream fileStream = store.CreateFile(fileName);
                fileStream.Write(data, 0, data.Length);
                fileStream.Close();

            }
        }

        private static byte[] ReadDataFromStore(string fileName)
        {
            using (var store = IsolatedStorageFile.GetStore(IsolatedStorageScope.User | IsolatedStorageScope.Domain | IsolatedStorageScope.Assembly, null, null))
            {
                IsolatedStorageFileStream fileStream;
                fileStream = store.OpenFile(fileName, FileMode.Open);
                byte[] b = new byte[fileStream.Length];
                fileStream.Read(b, 0, (int)fileStream.Length);
                fileStream.Close();
                return b;
            }
        }


        private static void CleanStorage(IsolatedStorageFile store)
        {
            String[] dirNames = store.GetDirectoryNames("*");
            String[] fileNames = store.GetFileNames("\\*");

            if (fileNames.Length > 0)
            {
                for (int i = 0; i < fileNames.Length; ++i)
                {
                    // Delete the files.
                    store.DeleteFile("\\" + fileNames[i]);
                }
                // Confirm that no files remain.
                fileNames = store.GetFileNames("\\*");
            }

            if (dirNames.Length > 0)
            {
                for (int i = 0; i < dirNames.Length; ++i)
                {
                    // Delete the Archive directory.
                    store.DeleteDirectory(dirNames[i]);
                }
            }
        }

        private void saveBtn_Click(object sender, RoutedEventArgs e)
        {
            XmlSerializer xs = new XmlSerializer(typeof(MyAppointment));
            MemoryStream str = new MemoryStream();
            StreamWriter sr = new StreamWriter(str);
            xs.Serialize(sr, MyAppointments[0]);
            WriteDataToStore(str.ToArray(), IsoFile);
        }

        private void loadBtn_Click(object sender, RoutedEventArgs e)
        {
            XmlSerializer xs = new XmlSerializer(typeof(MyAppointment));

            MemoryStream str = new MemoryStream(ReadDataFromStore(IsoFile));
            using (StreamReader rd = new StreamReader(str))
            {
                MyAppointment favourites = xs.Deserialize(rd) as MyAppointment;

            }
        }
    }

    public class MyResource
    {
        public string Id { get; set; }
        public string Name { get; set; }
    }
    public class MyResourceCalendar
    {
        public string Id { get; set; }
        public string OwningResourceId { get; set; }
    }

    public class MyAppointment
    {
        public string Id { get; set; }
        public DateTime Start { get; set; }
        public DateTime End { get; set; }
        public string OwningResourceId { get; set; }
        public string OwningCalendarId { get; set; }
        public string Subject { get; set; }
    }
}
